@@ -31,7 +31,7 @@ from tabulate import tabulate
 import yaml
 
 
-__version__ = "2.0.0"
+__version__ = "2.1.0"
 
 
 # Using this decorator in lieu of using a dependency to manage deprecation
@@ -348,7 +348,7 @@ def _convert_bytes_to_pretty_size(size_in_bytes: str, num_decimal_points: int =
     else:
         prettySize = round(prettySize, 2)
         prettySize = str(prettySize) + "KB"
-    
+
     return prettySize
 
 
@@ -358,7 +358,7 @@ def _convert_bytes_to_pretty_size(size_in_bytes: str, num_decimal_points: int =
 
 
 def clone_volume(new_volume_name: str, source_volume_name: str, source_snapshot_name: str = None,
-                 unix_uid: str = None, unix_gid: str = None, mountpoint: str = None,
+                 unix_uid: str = None, unix_gid: str = None, mountpoint: str = None, junction: str =None, readonly: bool = False,
                  print_output: bool = False):
     # Retrieve config details from config file
     try:
@@ -419,13 +419,19 @@ def clone_volume(new_volume_name: str, source_volume_name: str, source_snapshot_
                     print("Error: Invalid source volume name.")
                 raise InvalidVolumeParameterError("name")
 
+            # Create option to choose junction path.
+            if junction:
+                junction=junction
+            else:
+                junction = "/"+new_volume_name
+
             # Construct dict representing new volume
             newVolumeDict = {
                 "name": new_volume_name,
                 "comment": "netapp-dataops",
                 "svm": {"name": svm},
                 "nas": {
-                    "path": "/" + new_volume_name
+                    "path": junction
                 },
                 "clone": {
                     "is_flexclone": True,
@@ -479,7 +485,7 @@ def clone_volume(new_volume_name: str, source_volume_name: str, source_snapshot_
         # Optionally mount newly created volume
         if mountpoint:
             try:
-                mount_volume(volume_name=new_volume_name, mountpoint=mountpoint, print_output=True)
+                mount_volume(volume_name=new_volume_name, mountpoint=mountpoint, readonly=readonly, print_output=True)
             except (InvalidConfigError, APIConnectionError, InvalidVolumeParameterError, MountOperationError):
                 if print_output:
                     print("Error: Error mounting clone volume.")
@@ -555,7 +561,7 @@ def create_snapshot(volume_name: str, snapshot_name: str = None, print_output: b
 def create_volume(volume_name: str, volume_size: str, guarantee_space: bool = False,
                   volume_type: str = "flexvol", unix_permissions: str = "0777",
                   unix_uid: str = "0", unix_gid: str = "0", export_policy: str = "default",
-                  snapshot_policy: str = "none", aggregate: str = None, mountpoint: str = None,
+                  snapshot_policy: str = "none", aggregate: str = None, mountpoint: str = None, junction: str = None, readonly: bool = False,
                   print_output: bool = False):
     # Retrieve config details from config file
     try:
@@ -641,6 +647,13 @@ def create_volume(volume_name: str, volume_size: str, guarantee_space: bool = Fa
                 print("Error: Invalid volume size specified. Acceptable values are '1024MB', '100GB', '10TB', etc.")
             raise InvalidVolumeParameterError("size")
 
+        # Create option to choose junction path.
+        if junction:
+            junction=junction
+        else:
+            junction = "/"+volume_name
+
+
         # Create dict representing volume
         volumeDict = {
             "name": volume_name,
@@ -649,7 +662,7 @@ def create_volume(volume_name: str, volume_size: str, guarantee_space: bool = Fa
             "size": volumeSizeBytes,
             "style": volume_type,
             "nas": {
-                "path": "/" + volume_name,
+                "path": junction,
                 "export_policy": {"name": export_policy},
                 "security_style": "unix",
                 "unix_permissions": unix_permissions,
@@ -682,10 +695,12 @@ def create_volume(volume_name: str, volume_size: str, guarantee_space: bool = Fa
                 print("Error: ONTAP Rest API Error: ", err)
             raise APIConnectionError(err)
 
+
+
         # Optionally mount newly created volume
         if mountpoint:
             try:
-                mount_volume(volume_name=volume_name, mountpoint=mountpoint, print_output=True)
+                mount_volume(volume_name=volume_name, mountpoint=mountpoint, readonly=readonly, print_output=True)
             except (InvalidConfigError, APIConnectionError, InvalidVolumeParameterError, MountOperationError):
                 if print_output:
                     print("Error: Error mounting volume.")
@@ -1167,19 +1182,7 @@ def list_volumes(check_local_mounts: bool = False, include_space_usage_details:
         raise ConnectionTypeError()
 
 
-def mount_volume(volume_name: str, mountpoint: str, print_output: bool = False):
-    # Confirm that mountpoint value was passed in
-    if not mountpoint:
-        if print_output:
-            print("Error: No mountpoint specified.")
-        raise MountOperationError("No mountpoint")
-
-    # Confirm that volume name value was passed in
-    if not volume_name:
-        if print_output:
-            print("Error: No volume name specified.")
-        raise InvalidVolumeParameterError("name")
-
+def mount_volume(volume_name: str, mountpoint: str, readonly: bool = False, print_output: bool = False):
     nfsMountTarget = None
 
     # Retrieve list of volumes
@@ -1210,7 +1213,10 @@ def mount_volume(volume_name: str, mountpoint: str, print_output: bool = False):
 
     # Print message describing action to be understaken
     if print_output:
-        print("Mounting volume '" + volume_name + "' at '" + mountpoint + "'.")
+        if readonly:
+            print("Mounting volume '" + volume_name + "' at '" + mountpoint + "' as read-only.")
+        else:
+            print("Mounting volume '" + volume_name + "' at '" + mountpoint + "'.")
 
     # Create mountpoint if it doesn't already exist
     mountpoint = os.path.expanduser(mountpoint)
@@ -1220,13 +1226,41 @@ def mount_volume(volume_name: str, mountpoint: str, print_output: bool = False):
         pass
 
     # Mount volume
+    if readonly:
+        try:
+            subprocess.check_call(['mount', '-o', 'ro', nfsMountTarget, mountpoint])
+            if print_output:
+                print("Volume mounted successfully.")
+        except subprocess.CalledProcessError as err:
+            if print_output:
+                print("Error: Error running mount command: ", err)
+            raise MountOperationError(err)
+    else:
+        try:
+            subprocess.check_call(['mount', nfsMountTarget, mountpoint])
+            if print_output:
+                print("Volume mounted successfully.")
+        except subprocess.CalledProcessError as err:
+            if print_output:
+                print("Error: Error running mount command: ", err)
+            raise MountOperationError(err)
+
+
+
+# Function to unmount volume
+def unmount_volume(mountpoint: str, print_output: bool = False):
+    # Print message describing action to be understaken
+    if print_output:
+        print("Unmounting volume at '" + mountpoint + "'.")
+
+    # Un-mount volume
     try:
-        subprocess.check_call(['mount', nfsMountTarget, mountpoint])
+        subprocess.check_call(['umount', mountpoint])
         if print_output:
-            print("Volume mounted successfully.")
+            print("Volume unmounted successfully.")
     except subprocess.CalledProcessError as err:
         if print_output:
-            print("Error: Error running mount command: ", err)
+            print("Error: Error running unmount command: ", err)
         raise MountOperationError(err)
 
 
